@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: mime-types
-version: 0.1.0.6
-id: mime-types-0.1.0.6-7d5f22022675c00ea07fd0f1df020c2e
-key: mimet_9JBMcwv2Xiq5zZQuEgPby5
+version: 0.1.0.7
+id: mime-types-0.1.0.7-9c54fcb2a9f57168849ef5415f3582c2
+key: mimet_EkzgPOw2pX43Kgu0zxtOKD
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/yesodweb/wai
@@ -16,10 +16,10 @@ exposed: True
 exposed-modules:
     Network.Mime
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/mime-types-0.1.0.6
-library-dirs: /usr/lib/ghc-7.10.3/site-local/mime-types-0.1.0.6
-data-dir: /usr/share/arm-linux-ghc-7.10.3/mime-types-0.1.0.6
-hs-libraries: HSmime-types-0.1.0.6-9JBMcwv2Xiq5zZQuEgPby5
+import-dirs: /usr/lib/ghc-7.10.3/site-local/mime-types-0.1.0.7
+library-dirs: /usr/lib/ghc-7.10.3/site-local/mime-types-0.1.0.7
+data-dir: /usr/share/arm-linux-ghc-7.10.3/mime-types-0.1.0.7
+hs-libraries: HSmime-types-0.1.0.7-EkzgPOw2pX43Kgu0zxtOKD
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
